@@ -19,8 +19,8 @@
 ;; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 ;; USA
 
-;; Package-Version: 20260207.411
-;; Package-Revision: 36e5d5194bfc
+;; Package-Version: 20260228.1147
+;; Package-Revision: 4a149c0ad91f
 ;; Author: Sibi Prabakaran
 ;; Keywords: just justfile tools processes
 ;; URL: https://github.com/psibi/justl.el
@@ -181,7 +181,10 @@ Returns the absolute path if file exists or nil if no path
 was found."
   (cl-flet*
       ((is-justfile (s) (s-ends-with? "justfile" s t))
-       (any-justfile (d) (seq-find #'is-justfile (directory-files d))))
+       (any-justfile (d)
+         (let ((justfiles (seq-filter #'is-justfile (directory-files d))))
+           (or (seq-find (lambda (f) (string-equal f "justfile")) justfiles)
+               (car justfiles)))))
     (when-let ((location (locate-dominating-file dir #'any-justfile)))
       (expand-file-name (any-justfile location) location))))
 
